# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from continual.rpc.management.v1 import management_pb2 as continual_dot_rpc_dot_management_dot_v1_dot_management__pb2
from continual.rpc.management.v1 import management_types_pb2 as continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


class ManagementAPIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetServerVersion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetServerVersion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServerVersionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServerVersionResponse.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetUser',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUserRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
                )
        self.ListUsers = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListUsers',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersResponse.FromString,
                )
        self.BatchGetUsers = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetUsers',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersResponse.FromString,
                )
        self.UpdateUser = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateUser',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
                )
        self.DeleteUser = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteUser',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetViewer = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetViewer',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
                )
        self.Register = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/Register',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterResponse.FromString,
                )
        self.Login = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/Login',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginResponse.FromString,
                )
        self.Logout = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/Logout',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CheckOrganizationAccess = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CheckOrganizationAccess',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CheckOrganizationAccessRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CheckOrganizationAccessResponse.FromString,
                )
        self.GetPrincipal = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetPrincipal',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPrincipalRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Principal.FromString,
                )
        self.CheckViewer = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CheckViewer',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetApiKey = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetApiKey',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetApiKeyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ApiKey.FromString,
                )
        self.BatchGetApiKeys = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetApiKeys',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetApiKeysRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetApiKeysResponse.FromString,
                )
        self.ListApiKeys = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListApiKeys',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListApiKeysRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListApiKeysResponse.FromString,
                )
        self.CreateApiKey = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateApiKey',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateApiKeyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ApiKey.FromString,
                )
        self.UpdateApiKey = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateApiKey',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateApiKeyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ApiKey.FromString,
                )
        self.RevokeApiKey = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/RevokeApiKey',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RevokeApiKeyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetApiKeyProject = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetApiKeyProject',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetApiKeyProjectRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
                )
        self.SendEmailVerification = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/SendEmailVerification',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendEmailVerificationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.VerifyEmail = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/VerifyEmail',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailResponse.FromString,
                )
        self.SendPasswordReset = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/SendPasswordReset',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendPasswordResetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ResetPassword = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ResetPassword',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordResponse.FromString,
                )
        self.ChangePassword = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ChangePassword',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ChangePasswordRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ChangePasswordResponse.FromString,
                )
        self.GetSession = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetSession',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSessionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Session.FromString,
                )
        self.ListSessions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListSessions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsResponse.FromString,
                )
        self.DeleteSession = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteSession',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteSessionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteAllSessions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteAllSessions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAllSessionsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetOrganization = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetOrganization',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
                )
        self.BatchGetOrganizations = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetOrganizations',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsResponse.FromString,
                )
        self.ListOrganizations = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListOrganizations',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsResponse.FromString,
                )
        self.CreateOrganization = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateOrganization',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateOrganizationRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
                )
        self.UpdateOrganization = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateOrganization',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOrganizationRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
                )
        self.DeleteOrganization = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteOrganization',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteOrganizationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetOnboarding = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetOnboarding',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOnboardingRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.FromString,
                )
        self.UpdateOnboarding = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateOnboarding',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOnboardingRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.FromString,
                )
        self.ListRoles = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListRoles',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesResponse.FromString,
                )
        self.GetRole = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetRole',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRoleRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Role.FromString,
                )
        self.BatchGetRoles = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetRoles',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesResponse.FromString,
                )
        self.CreateAccessPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateAccessPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateAccessPolicyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
                )
        self.GetAccessPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetAccessPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetAccessPolicyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
                )
        self.ListAccessPolicies = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListAccessPolicies',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesResponse.FromString,
                )
        self.BulkDeleteAccessPolicies = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BulkDeleteAccessPolicies',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BulkDeleteAccessPoliciesRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteAccessPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteAccessPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAccessPolicyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateAccessPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateAccessPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateAccessPolicyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
                )
        self.TestPermissions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/TestPermissions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsResponse.FromString,
                )
        self.CreateInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateInviteRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
                )
        self.GetInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInviteRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
                )
        self.ListInvites = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListInvites',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesResponse.FromString,
                )
        self.UpdateInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateInviteRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
                )
        self.ResendInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ResendInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResendInviteRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
                )
        self.DeleteInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteInviteRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.AcceptInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/AcceptInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.AcceptInviteRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetProject = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetProject',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
                )
        self.BatchGetProjects = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetProjects',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsResponse.FromString,
                )
        self.ListProjects = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListProjects',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsResponse.FromString,
                )
        self.CreateProject = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateProject',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
                )
        self.UpdateProject = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateProject',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
                )
        self.DeleteProject = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteProject',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteProjectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreatePromotion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreatePromotion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreatePromotionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.FromString,
                )
        self.ListPromotions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListPromotions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsResponse.FromString,
                )
        self.GetPromotion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetPromotion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPromotionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.FromString,
                )
        self.BatchGetPromotions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetPromotions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsResponse.FromString,
                )
        self.ListEvents = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListEvents',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsResponse.FromString,
                )
        self.GetEvent = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetEvent',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEventRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Event.FromString,
                )
        self.BatchGetEvents = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetEvents',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsResponse.FromString,
                )
        self.CreateEvent = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateEvent',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateEventRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetSubscription = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetSubscription',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSubscriptionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.FromString,
                )
        self.GetBillingAccount = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetBillingAccount',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetBillingAccountRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.FromString,
                )
        self.GetUsage = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetUsage',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageResponse.FromString,
                )
        self.ListInvoices = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListInvoices',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesResponse.FromString,
                )
        self.UpdateBillingAccount = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateBillingAccount',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateBillingAccountRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.FromString,
                )
        self.UpdateSubscription = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateSubscription',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateSubscriptionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.FromString,
                )
        self.ListPrices = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListPrices',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesResponse.FromString,
                )
        self.GetPrice = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetPrice',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPriceRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Price.FromString,
                )
        self.GetPaymentMethod = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetPaymentMethod',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPaymentMethodRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.PaymentMethod.FromString,
                )
        self.GetUpcomingInvoice = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetUpcomingInvoice',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUpcomingInvoiceRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invoice.FromString,
                )
        self.CreateModel = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateModel',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateModelRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Model.FromString,
                )
        self.GetModel = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetModel',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Model.FromString,
                )
        self.BatchGetModels = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetModels',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsResponse.FromString,
                )
        self.ListModels = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListModels',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsResponse.FromString,
                )
        self.DeleteModel = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteModel',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteModelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateModelVersion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateModelVersion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateModelVersionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.FromString,
                )
        self.GetModelVersion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetModelVersion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.FromString,
                )
        self.BatchGetModelVersions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetModelVersions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsResponse.FromString,
                )
        self.ListModelVersions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListModelVersions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsResponse.FromString,
                )
        self.CreateBatchPrediction = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateBatchPrediction',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateBatchPredictionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.FromString,
                )
        self.GetBatchPrediction = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetBatchPrediction',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchPredictionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.FromString,
                )
        self.BatchGetBatchPredictions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetBatchPredictions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsResponse.FromString,
                )
        self.ListBatchPredictions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListBatchPredictions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsResponse.FromString,
                )
        self.CreateExperiment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateExperiment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateExperimentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Experiment.FromString,
                )
        self.GetExperiment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetExperiment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetExperimentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Experiment.FromString,
                )
        self.BatchGetExperiments = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetExperiments',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsResponse.FromString,
                )
        self.ListExperiments = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListExperiments',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsResponse.FromString,
                )
        self.GetEnvironment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetEnvironment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEnvironmentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
                )
        self.BatchGetEnvironments = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetEnvironments',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsResponse.FromString,
                )
        self.ListEnvironments = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListEnvironments',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsResponse.FromString,
                )
        self.CreateEnvironment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateEnvironment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateEnvironmentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
                )
        self.UpdateEnvironment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateEnvironment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateEnvironmentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
                )
        self.DeleteEnvironment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteEnvironment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteEnvironmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetSystemMessage = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetSystemMessage',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageResponse.FromString,
                )
        self.GetFeatureFlag = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetFeatureFlag',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureFlagRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureFlagResponse.FromString,
                )
        self.GetOrganizationFeatureFlags = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetOrganizationFeatureFlags',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationFeatureFlagsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationFeatureFlagsResponse.FromString,
                )
        self.CreateArtifact = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateArtifact',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateArtifactRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Artifact.FromString,
                )
        self.GetArtifact = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetArtifact',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetArtifactRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Artifact.FromString,
                )
        self.BatchGetArtifacts = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetArtifacts',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetArtifactsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetArtifactsResponse.FromString,
                )
        self.DeleteArtifact = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteArtifact',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteArtifactRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GenerateArtifactUploadURL = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GenerateArtifactUploadURL',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateArtifactUploadURLRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateArtifactUploadURLResponse.FromString,
                )
        self.ListArtifacts = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListArtifacts',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListArtifactsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListArtifactsResponse.FromString,
                )
        self.ListUserIntegrationProviders = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListUserIntegrationProviders',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationProvidersRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationProvidersResponse.FromString,
                )
        self.ListUserIntegrations = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListUserIntegrations',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationsResponse.FromString,
                )
        self.DisconnectUserIntegration = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DisconnectUserIntegration',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DisconnectUserIntegrationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GenerateSsoAdminPortalURL = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GenerateSsoAdminPortalURL',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateSsoAdminPortalURLRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateSsoAdminPortalURLResponse.FromString,
                )
        self.GenerateDSyncAdminPortalURL = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GenerateDSyncAdminPortalURL',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateDSyncAdminPortalURLRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateDSyncAdminPortalURLResponse.FromString,
                )
        self.ExchangeToken = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ExchangeToken',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ExchangeTokenRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ExchangeTokenResponse.FromString,
                )
        self.ListGitProviderNamespaces = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListGitProviderNamespaces',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderNamespacesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderNamespacesResponse.FromString,
                )
        self.ListGitProviderRepositories = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListGitProviderRepositories',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderRepositoriesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderRepositoriesResponse.FromString,
                )
        self.ConnectProjectToGitRepository = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ConnectProjectToGitRepository',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ConnectProjectToGitRepositoryRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ConnectProjectToGitRepositoryResponse.FromString,
                )
        self.GetProjectGitIntegration = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetProjectGitIntegration',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetProjectGitIntegrationRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ProjectGitIntegration.FromString,
                )
        self.SeedProjectGitRepository = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/SeedProjectGitRepository',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SeedProjectGitRepositoryRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetRun = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetRun',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRunRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Run.FromString,
                )
        self.BatchGetRuns = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetRuns',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRunsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRunsResponse.FromString,
                )
        self.ListRuns = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListRuns',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRunsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRunsResponse.FromString,
                )
        self.CreateRun = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateRun',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateRunRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Run.FromString,
                )
        self.UpdateRun = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateRun',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateRunRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Run.FromString,
                )
        self.DeleteRun = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteRun',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteRunRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetRunSummary = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetRunSummary',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRunSummaryRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.RunSummary.FromString,
                )
        self.GetRunCheckSummary = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetRunCheckSummary',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRunCheckSummaryRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.RunCheckSummary.FromString,
                )
        self.LogRunHeartbeat = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/LogRunHeartbeat',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LogRunHeartbeatRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_timestamp__pb2.Timestamp.FromString,
                )
        self.GetMetric = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetMetric',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetMetricRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metric.FromString,
                )
        self.BatchGetMetrics = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetMetrics',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetricsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetricsResponse.FromString,
                )
        self.ListMetrics = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListMetrics',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetricsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetricsResponse.FromString,
                )
        self.CreateMetric = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateMetric',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateMetricRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metric.FromString,
                )
        self.LogMetric = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/LogMetric',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LogMetricRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateMetric = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateMetric',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateMetricRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metric.FromString,
                )
        self.GetMetadata = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetMetadata',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetMetadataRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metadata.FromString,
                )
        self.BatchGetMetadata = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetMetadata',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetadataRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetadataResponse.FromString,
                )
        self.ListMetadata = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListMetadata',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetadataRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetadataResponse.FromString,
                )
        self.CreateMetadata = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateMetadata',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateMetadataRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metadata.FromString,
                )
        self.UpdateMetadata = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateMetadata',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateMetadataRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metadata.FromString,
                )
        self.DeleteMetadata = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteMetadata',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteMetadataRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetNotificationPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetNotificationPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetNotificationPolicyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.NotificationPolicy.FromString,
                )
        self.BatchGetNotificationPolicies = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetNotificationPolicies',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetNotificationPoliciesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetNotificationPoliciesResponse.FromString,
                )
        self.ListNotificationPolicies = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListNotificationPolicies',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListNotificationPoliciesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListNotificationPoliciesResponse.FromString,
                )
        self.CreateNotificationPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateNotificationPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateNotificationPolicyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.NotificationPolicy.FromString,
                )
        self.UpdateNotificationPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateNotificationPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateNotificationPolicyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.NotificationPolicy.FromString,
                )
        self.DeleteNotificationPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteNotificationPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteNotificationPolicyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetTag = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetTag',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTagRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Tag.FromString,
                )
        self.BatchGetTags = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetTags',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetTagsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetTagsResponse.FromString,
                )
        self.ListTags = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListTags',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTagsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTagsResponse.FromString,
                )
        self.CreateTag = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateTag',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateTagRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Tag.FromString,
                )
        self.UpdateTag = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateTag',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateTagRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Tag.FromString,
                )
        self.DeleteTag = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteTag',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteTagRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetResourceCheck = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetResourceCheck',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetResourceCheckRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ResourceCheck.FromString,
                )
        self.ListResourceChecks = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListResourceChecks',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListResourceChecksRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListResourceChecksResponse.FromString,
                )
        self.CreateResourceCheck = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateResourceCheck',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateResourceCheckRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ResourceCheck.FromString,
                )
        self.GetDataProfile = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetDataProfile',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDataProfileRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DataProfile.FromString,
                )
        self.ListDataProfiles = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListDataProfiles',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDataProfilesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDataProfilesResponse.FromString,
                )
        self.CreateDataProfile = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateDataProfile',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDataProfileRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DataProfile.FromString,
                )
        self.UpdateDataProfile = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateDataProfile',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateDataProfileRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DataProfile.FromString,
                )
        self.CreateDataset = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateDataset',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDatasetRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Dataset.FromString,
                )
        self.GetDataset = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetDataset',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDatasetRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Dataset.FromString,
                )
        self.BatchGetDatasets = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetDatasets',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetsResponse.FromString,
                )
        self.ListDatasets = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListDatasets',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetsResponse.FromString,
                )
        self.DeleteDataset = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteDataset',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteDatasetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateDatasetVersion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateDatasetVersion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDatasetVersionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersion.FromString,
                )
        self.GetDatasetVersion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetDatasetVersion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDatasetVersionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersion.FromString,
                )
        self.BatchGetDatasetVersions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetDatasetVersions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetVersionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetVersionsResponse.FromString,
                )
        self.ListDatasetVersions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListDatasetVersions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionsResponse.FromString,
                )
        self.CreateDatasetVersionAssignment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateDatasetVersionAssignment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDatasetVersionAssignmentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersionAssignment.FromString,
                )
        self.GetDatasetVersionAssignment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetDatasetVersionAssignment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDatasetVersionAssignmentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersionAssignment.FromString,
                )
        self.DeleteDatasetVersionAssignment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteDatasetVersionAssignment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteDatasetVersionAssignmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListDatasetVersionAssignments = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListDatasetVersionAssignments',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionAssignmentsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionAssignmentsResponse.FromString,
                )


class ManagementAPIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetServerVersion(self, request, context):
        """Client/Server Version
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """USERS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetViewer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Register(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckOrganizationAccess(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPrincipal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckViewer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApiKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetApiKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListApiKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateApiKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateApiKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeApiKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApiKeyProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendEmailVerification(self, request, context):
        """EMAIL VERIFICATION

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendPasswordReset(self, request, context):
        """PASSWORD RESETS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetPassword(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangePassword(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSession(self, request, context):
        """SESSIONS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSessions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAllSessions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganization(self, request, context):
        """ORGANIZATIONS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetOrganizations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOnboarding(self, request, context):
        """Onboarding

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOnboarding(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRoles(self, request, context):
        """IAM / ACCESS MANAGEMENT

        List all all roles.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRole(self, request, context):
        """Get details about a role, such as as the permissions granted.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccessPolicy(self, request, context):
        """Sets the access control policy of a subject on a resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccessPolicy(self, request, context):
        """Gets the access control policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessPolicies(self, request, context):
        """Lists the access control policies for a resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BulkDeleteAccessPolicies(self, request, context):
        """Delete the access control policy for a subject on a resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAccessPolicy(self, request, context):
        """Delete the access control policy for a subject on a resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestPermissions(self, request, context):
        """Returns permissions that a caller has on the specified resource.
        If the resource does not exist, this will return an empty set of
        permissions, not a NOT_FOUND error.

        Note: This operation is designed to be used for building permission-aware
        UIs and command-line tools, not for authorization checking.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInvite(self, request, context):
        """Invites

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInvites(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResendInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProject(self, request, context):
        """PROJECTS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetProjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePromotion(self, request, context):
        """PROMOTIONS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPromotions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPromotion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetPromotions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEvents(self, request, context):
        """Events 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetEvents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSubscription(self, request, context):
        """Billing
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBillingAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUsage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInvoices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBillingAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSubscription(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPrices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPrice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPaymentMethod(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpcomingInvoice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModel(self, request, context):
        """MODELS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetModels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelVersion(self, request, context):
        """MODEL VERSIONS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetModelVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModelVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBatchPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetBatchPredictions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBatchPredictions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateExperiment(self, request, context):
        """Experiments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExperiment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetExperiments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExperiments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironment(self, request, context):
        """ENVIRONMENTS

        option (google.api.http) = {
        get : "/v1/{name=projects/*}"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetEnvironments(self, request, context):
        """option (google.api.http) = {
        get : "/v1/projects:batchGet"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEnvironments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEnvironment(self, request, context):
        """option (google.api.http) = {
        post : "/v1/projects"
        body : "project"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironment(self, request, context):
        """option (google.api.http) = {
        patch : "/v1/{project.name=projects/*}"
        body : "project"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEnvironment(self, request, context):
        """option (google.api.http) = {
        delete : "/v1/{name=projects/*}"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSystemMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureFlag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationFeatureFlags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateArtifact(self, request, context):
        """Artifacts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetArtifacts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateArtifactUploadURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListArtifacts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserIntegrationProviders(self, request, context):
        """USER INTEGRATIONS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserIntegrations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisconnectUserIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateSsoAdminPortalURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateDSyncAdminPortalURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExchangeToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListGitProviderNamespaces(self, request, context):
        """GIT

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListGitProviderRepositories(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectProjectToGitRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectGitIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SeedProjectGitRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRun(self, request, context):
        """RUNS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRunSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRunCheckSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LogRunHeartbeat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetric(self, request, context):
        """METRICS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMetric(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LogMetric(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMetric(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetadata(self, request, context):
        """METADATA
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotificationPolicy(self, request, context):
        """NOTIFICATION POLICY
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetNotificationPolicies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNotificationPolicies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNotificationPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNotificationPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNotificationPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTag(self, request, context):
        """TAGS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResourceCheck(self, request, context):
        """Resource Checks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListResourceChecks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateResourceCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataProfile(self, request, context):
        """Data Profiles
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDataProfiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataset(self, request, context):
        """Datasets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetDatasets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDatasets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDatasetVersion(self, request, context):
        """Dataset versions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatasetVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetDatasetVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDatasetVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDatasetVersionAssignment(self, request, context):
        """dataset version associations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatasetVersionAssignment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDatasetVersionAssignment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDatasetVersionAssignments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ManagementAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetServerVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServerVersion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServerVersionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServerVersionResponse.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUserRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersResponse.SerializeToString,
            ),
            'BatchGetUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetUsers,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersResponse.SerializeToString,
            ),
            'UpdateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUser,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateUserRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteUserRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetViewer': grpc.unary_unary_rpc_method_handler(
                    servicer.GetViewer,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.SerializeToString,
            ),
            'Register': grpc.unary_unary_rpc_method_handler(
                    servicer.Register,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterResponse.SerializeToString,
            ),
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginResponse.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CheckOrganizationAccess': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckOrganizationAccess,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CheckOrganizationAccessRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CheckOrganizationAccessResponse.SerializeToString,
            ),
            'GetPrincipal': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPrincipal,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPrincipalRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Principal.SerializeToString,
            ),
            'CheckViewer': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckViewer,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApiKey,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetApiKeyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ApiKey.SerializeToString,
            ),
            'BatchGetApiKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetApiKeys,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetApiKeysRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetApiKeysResponse.SerializeToString,
            ),
            'ListApiKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApiKeys,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListApiKeysRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListApiKeysResponse.SerializeToString,
            ),
            'CreateApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateApiKey,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateApiKeyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ApiKey.SerializeToString,
            ),
            'UpdateApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateApiKey,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateApiKeyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ApiKey.SerializeToString,
            ),
            'RevokeApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeApiKey,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RevokeApiKeyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetApiKeyProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApiKeyProject,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetApiKeyProjectRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.SerializeToString,
            ),
            'SendEmailVerification': grpc.unary_unary_rpc_method_handler(
                    servicer.SendEmailVerification,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendEmailVerificationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'VerifyEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyEmail,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailResponse.SerializeToString,
            ),
            'SendPasswordReset': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPasswordReset,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendPasswordResetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ResetPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetPassword,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordResponse.SerializeToString,
            ),
            'ChangePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangePassword,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ChangePasswordRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ChangePasswordResponse.SerializeToString,
            ),
            'GetSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSession,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSessionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Session.SerializeToString,
            ),
            'ListSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSessions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsResponse.SerializeToString,
            ),
            'DeleteSession': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSession,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteSessionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteAllSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAllSessions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAllSessionsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganization,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.SerializeToString,
            ),
            'BatchGetOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetOrganizations,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsResponse.SerializeToString,
            ),
            'ListOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizations,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsResponse.SerializeToString,
            ),
            'CreateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganization,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateOrganizationRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.SerializeToString,
            ),
            'UpdateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganization,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOrganizationRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.SerializeToString,
            ),
            'DeleteOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganization,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteOrganizationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetOnboarding': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOnboarding,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOnboardingRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.SerializeToString,
            ),
            'UpdateOnboarding': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOnboarding,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOnboardingRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.SerializeToString,
            ),
            'ListRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRoles,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesResponse.SerializeToString,
            ),
            'GetRole': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRole,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRoleRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Role.SerializeToString,
            ),
            'BatchGetRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetRoles,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesResponse.SerializeToString,
            ),
            'CreateAccessPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccessPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateAccessPolicyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.SerializeToString,
            ),
            'GetAccessPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccessPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetAccessPolicyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.SerializeToString,
            ),
            'ListAccessPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessPolicies,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesResponse.SerializeToString,
            ),
            'BulkDeleteAccessPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.BulkDeleteAccessPolicies,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BulkDeleteAccessPoliciesRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteAccessPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAccessPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAccessPolicyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateAccessPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateAccessPolicyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.SerializeToString,
            ),
            'TestPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.TestPermissions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsResponse.SerializeToString,
            ),
            'CreateInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateInviteRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.SerializeToString,
            ),
            'GetInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInviteRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.SerializeToString,
            ),
            'ListInvites': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInvites,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesResponse.SerializeToString,
            ),
            'UpdateInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateInviteRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.SerializeToString,
            ),
            'ResendInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.ResendInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResendInviteRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.SerializeToString,
            ),
            'DeleteInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteInviteRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'AcceptInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.AcceptInviteRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProject,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetProjectRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.SerializeToString,
            ),
            'BatchGetProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetProjects,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsResponse.SerializeToString,
            ),
            'ListProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjects,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsResponse.SerializeToString,
            ),
            'CreateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProject,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateProjectRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.SerializeToString,
            ),
            'UpdateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProject,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateProjectRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.SerializeToString,
            ),
            'DeleteProject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProject,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteProjectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreatePromotion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePromotion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreatePromotionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.SerializeToString,
            ),
            'ListPromotions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPromotions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsResponse.SerializeToString,
            ),
            'GetPromotion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPromotion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPromotionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.SerializeToString,
            ),
            'BatchGetPromotions': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetPromotions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsResponse.SerializeToString,
            ),
            'ListEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEvents,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsResponse.SerializeToString,
            ),
            'GetEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvent,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEventRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Event.SerializeToString,
            ),
            'BatchGetEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetEvents,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsResponse.SerializeToString,
            ),
            'CreateEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEvent,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateEventRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSubscription,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSubscriptionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.SerializeToString,
            ),
            'GetBillingAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBillingAccount,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetBillingAccountRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.SerializeToString,
            ),
            'GetUsage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsage,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageResponse.SerializeToString,
            ),
            'ListInvoices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInvoices,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesResponse.SerializeToString,
            ),
            'UpdateBillingAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBillingAccount,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateBillingAccountRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.SerializeToString,
            ),
            'UpdateSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSubscription,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateSubscriptionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.SerializeToString,
            ),
            'ListPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPrices,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesResponse.SerializeToString,
            ),
            'GetPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPrice,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPriceRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Price.SerializeToString,
            ),
            'GetPaymentMethod': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPaymentMethod,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPaymentMethodRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.PaymentMethod.SerializeToString,
            ),
            'GetUpcomingInvoice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUpcomingInvoice,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUpcomingInvoiceRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invoice.SerializeToString,
            ),
            'CreateModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModel,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateModelRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Model.SerializeToString,
            ),
            'GetModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModel,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Model.SerializeToString,
            ),
            'BatchGetModels': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetModels,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsResponse.SerializeToString,
            ),
            'ListModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModels,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsResponse.SerializeToString,
            ),
            'DeleteModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModel,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteModelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelVersion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateModelVersionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.SerializeToString,
            ),
            'GetModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelVersion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.SerializeToString,
            ),
            'BatchGetModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetModelVersions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsResponse.SerializeToString,
            ),
            'ListModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelVersions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsResponse.SerializeToString,
            ),
            'CreateBatchPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBatchPrediction,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateBatchPredictionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.SerializeToString,
            ),
            'GetBatchPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchPrediction,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchPredictionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.SerializeToString,
            ),
            'BatchGetBatchPredictions': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetBatchPredictions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsResponse.SerializeToString,
            ),
            'ListBatchPredictions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBatchPredictions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsResponse.SerializeToString,
            ),
            'CreateExperiment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateExperiment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateExperimentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Experiment.SerializeToString,
            ),
            'GetExperiment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExperiment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetExperimentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Experiment.SerializeToString,
            ),
            'BatchGetExperiments': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetExperiments,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsResponse.SerializeToString,
            ),
            'ListExperiments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExperiments,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsResponse.SerializeToString,
            ),
            'GetEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEnvironmentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.SerializeToString,
            ),
            'BatchGetEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetEnvironments,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsResponse.SerializeToString,
            ),
            'ListEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEnvironments,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsResponse.SerializeToString,
            ),
            'CreateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateEnvironmentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.SerializeToString,
            ),
            'UpdateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateEnvironmentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.SerializeToString,
            ),
            'DeleteEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEnvironment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteEnvironmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetSystemMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSystemMessage,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageResponse.SerializeToString,
            ),
            'GetFeatureFlag': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureFlag,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureFlagRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureFlagResponse.SerializeToString,
            ),
            'GetOrganizationFeatureFlags': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationFeatureFlags,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationFeatureFlagsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationFeatureFlagsResponse.SerializeToString,
            ),
            'CreateArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateArtifact,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateArtifactRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Artifact.SerializeToString,
            ),
            'GetArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.GetArtifact,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetArtifactRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Artifact.SerializeToString,
            ),
            'BatchGetArtifacts': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetArtifacts,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetArtifactsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetArtifactsResponse.SerializeToString,
            ),
            'DeleteArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteArtifact,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteArtifactRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GenerateArtifactUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateArtifactUploadURL,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateArtifactUploadURLRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateArtifactUploadURLResponse.SerializeToString,
            ),
            'ListArtifacts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListArtifacts,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListArtifactsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListArtifactsResponse.SerializeToString,
            ),
            'ListUserIntegrationProviders': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserIntegrationProviders,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationProvidersRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationProvidersResponse.SerializeToString,
            ),
            'ListUserIntegrations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserIntegrations,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationsResponse.SerializeToString,
            ),
            'DisconnectUserIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DisconnectUserIntegration,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DisconnectUserIntegrationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GenerateSsoAdminPortalURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateSsoAdminPortalURL,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateSsoAdminPortalURLRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateSsoAdminPortalURLResponse.SerializeToString,
            ),
            'GenerateDSyncAdminPortalURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateDSyncAdminPortalURL,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateDSyncAdminPortalURLRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateDSyncAdminPortalURLResponse.SerializeToString,
            ),
            'ExchangeToken': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeToken,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ExchangeTokenRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ExchangeTokenResponse.SerializeToString,
            ),
            'ListGitProviderNamespaces': grpc.unary_unary_rpc_method_handler(
                    servicer.ListGitProviderNamespaces,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderNamespacesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderNamespacesResponse.SerializeToString,
            ),
            'ListGitProviderRepositories': grpc.unary_unary_rpc_method_handler(
                    servicer.ListGitProviderRepositories,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderRepositoriesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderRepositoriesResponse.SerializeToString,
            ),
            'ConnectProjectToGitRepository': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectProjectToGitRepository,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ConnectProjectToGitRepositoryRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ConnectProjectToGitRepositoryResponse.SerializeToString,
            ),
            'GetProjectGitIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectGitIntegration,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetProjectGitIntegrationRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ProjectGitIntegration.SerializeToString,
            ),
            'SeedProjectGitRepository': grpc.unary_unary_rpc_method_handler(
                    servicer.SeedProjectGitRepository,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SeedProjectGitRepositoryRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRun,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRunRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Run.SerializeToString,
            ),
            'BatchGetRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetRuns,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRunsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRunsResponse.SerializeToString,
            ),
            'ListRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRuns,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRunsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRunsResponse.SerializeToString,
            ),
            'CreateRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRun,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateRunRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Run.SerializeToString,
            ),
            'UpdateRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRun,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateRunRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Run.SerializeToString,
            ),
            'DeleteRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRun,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteRunRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetRunSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunSummary,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRunSummaryRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.RunSummary.SerializeToString,
            ),
            'GetRunCheckSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunCheckSummary,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRunCheckSummaryRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.RunCheckSummary.SerializeToString,
            ),
            'LogRunHeartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.LogRunHeartbeat,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LogRunHeartbeatRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_timestamp__pb2.Timestamp.SerializeToString,
            ),
            'GetMetric': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetric,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetMetricRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metric.SerializeToString,
            ),
            'BatchGetMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetMetrics,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetricsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetricsResponse.SerializeToString,
            ),
            'ListMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMetrics,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetricsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetricsResponse.SerializeToString,
            ),
            'CreateMetric': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMetric,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateMetricRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metric.SerializeToString,
            ),
            'LogMetric': grpc.unary_unary_rpc_method_handler(
                    servicer.LogMetric,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LogMetricRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateMetric': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMetric,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateMetricRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metric.SerializeToString,
            ),
            'GetMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetadata,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetMetadataRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metadata.SerializeToString,
            ),
            'BatchGetMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetMetadata,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetadataRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetadataResponse.SerializeToString,
            ),
            'ListMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMetadata,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetadataRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetadataResponse.SerializeToString,
            ),
            'CreateMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMetadata,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateMetadataRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metadata.SerializeToString,
            ),
            'UpdateMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMetadata,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateMetadataRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metadata.SerializeToString,
            ),
            'DeleteMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMetadata,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteMetadataRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetNotificationPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotificationPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetNotificationPolicyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.NotificationPolicy.SerializeToString,
            ),
            'BatchGetNotificationPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetNotificationPolicies,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetNotificationPoliciesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetNotificationPoliciesResponse.SerializeToString,
            ),
            'ListNotificationPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNotificationPolicies,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListNotificationPoliciesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListNotificationPoliciesResponse.SerializeToString,
            ),
            'CreateNotificationPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNotificationPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateNotificationPolicyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.NotificationPolicy.SerializeToString,
            ),
            'UpdateNotificationPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNotificationPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateNotificationPolicyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.NotificationPolicy.SerializeToString,
            ),
            'DeleteNotificationPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNotificationPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteNotificationPolicyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetTag': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTag,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTagRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Tag.SerializeToString,
            ),
            'BatchGetTags': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetTags,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetTagsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetTagsResponse.SerializeToString,
            ),
            'ListTags': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTags,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTagsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTagsResponse.SerializeToString,
            ),
            'CreateTag': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTag,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateTagRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Tag.SerializeToString,
            ),
            'UpdateTag': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTag,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateTagRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Tag.SerializeToString,
            ),
            'DeleteTag': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTag,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteTagRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetResourceCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResourceCheck,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetResourceCheckRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ResourceCheck.SerializeToString,
            ),
            'ListResourceChecks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListResourceChecks,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListResourceChecksRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListResourceChecksResponse.SerializeToString,
            ),
            'CreateResourceCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateResourceCheck,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateResourceCheckRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ResourceCheck.SerializeToString,
            ),
            'GetDataProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataProfile,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDataProfileRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DataProfile.SerializeToString,
            ),
            'ListDataProfiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataProfiles,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDataProfilesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDataProfilesResponse.SerializeToString,
            ),
            'CreateDataProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataProfile,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDataProfileRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DataProfile.SerializeToString,
            ),
            'UpdateDataProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataProfile,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateDataProfileRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DataProfile.SerializeToString,
            ),
            'CreateDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataset,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDatasetRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Dataset.SerializeToString,
            ),
            'GetDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataset,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDatasetRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Dataset.SerializeToString,
            ),
            'BatchGetDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetDatasets,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetsResponse.SerializeToString,
            ),
            'ListDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDatasets,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetsResponse.SerializeToString,
            ),
            'DeleteDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataset,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteDatasetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateDatasetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatasetVersion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDatasetVersionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersion.SerializeToString,
            ),
            'GetDatasetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatasetVersion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDatasetVersionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersion.SerializeToString,
            ),
            'BatchGetDatasetVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetDatasetVersions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetVersionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetVersionsResponse.SerializeToString,
            ),
            'ListDatasetVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDatasetVersions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionsResponse.SerializeToString,
            ),
            'CreateDatasetVersionAssignment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatasetVersionAssignment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDatasetVersionAssignmentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersionAssignment.SerializeToString,
            ),
            'GetDatasetVersionAssignment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatasetVersionAssignment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDatasetVersionAssignmentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersionAssignment.SerializeToString,
            ),
            'DeleteDatasetVersionAssignment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDatasetVersionAssignment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteDatasetVersionAssignmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListDatasetVersionAssignments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDatasetVersionAssignments,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionAssignmentsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionAssignmentsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'continual.rpc.management.v1.ManagementAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ManagementAPI(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetServerVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetServerVersion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServerVersionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServerVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetUser',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUserRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListUsers',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetUsers',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateUser',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateUserRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteUser',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteUserRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetViewer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetViewer',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/Register',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/Login',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/Logout',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckOrganizationAccess(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CheckOrganizationAccess',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CheckOrganizationAccessRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CheckOrganizationAccessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPrincipal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetPrincipal',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPrincipalRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Principal.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckViewer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CheckViewer',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetApiKey',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetApiKeyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ApiKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetApiKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetApiKeys',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetApiKeysRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetApiKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListApiKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListApiKeys',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListApiKeysRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListApiKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateApiKey',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateApiKeyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ApiKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateApiKey',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateApiKeyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ApiKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/RevokeApiKey',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RevokeApiKeyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApiKeyProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetApiKeyProject',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetApiKeyProjectRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendEmailVerification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/SendEmailVerification',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendEmailVerificationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/VerifyEmail',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendPasswordReset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/SendPasswordReset',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendPasswordResetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ResetPassword',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ChangePassword',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ChangePasswordRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ChangePasswordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetSession',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSessionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Session.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListSessions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteSession',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteSessionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAllSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteAllSessions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAllSessionsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetOrganization',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetOrganizations',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListOrganizations',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateOrganization',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateOrganizationRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateOrganization',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOrganizationRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteOrganization',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteOrganizationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOnboarding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetOnboarding',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOnboardingRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOnboarding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateOnboarding',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOnboardingRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListRoles',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetRole',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRoleRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Role.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetRoles',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAccessPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateAccessPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateAccessPolicyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccessPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetAccessPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetAccessPolicyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListAccessPolicies',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BulkDeleteAccessPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BulkDeleteAccessPolicies',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BulkDeleteAccessPoliciesRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAccessPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteAccessPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAccessPolicyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateAccessPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateAccessPolicyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/TestPermissions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateInviteRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInviteRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInvites(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListInvites',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateInviteRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResendInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ResendInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResendInviteRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteInviteRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AcceptInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/AcceptInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.AcceptInviteRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetProject',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetProjectRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetProjects',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListProjects',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateProject',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateProjectRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateProject',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateProjectRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteProject',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteProjectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePromotion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreatePromotion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreatePromotionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPromotions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListPromotions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPromotion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetPromotion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPromotionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetPromotions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetPromotions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListEvents',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetEvent',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEventRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Event.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetEvents',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateEvent',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateEventRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetSubscription',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSubscriptionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBillingAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetBillingAccount',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetBillingAccountRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUsage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetUsage',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInvoices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListInvoices',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBillingAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateBillingAccount',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateBillingAccountRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateSubscription',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateSubscriptionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListPrices',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetPrice',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPriceRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Price.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPaymentMethod(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetPaymentMethod',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPaymentMethodRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.PaymentMethod.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUpcomingInvoice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetUpcomingInvoice',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUpcomingInvoiceRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invoice.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateModel',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateModelRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Model.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetModel',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Model.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetModels',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListModels',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteModel',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteModelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateModelVersion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateModelVersionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetModelVersion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetModelVersions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListModelVersions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateBatchPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateBatchPrediction',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateBatchPredictionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetBatchPrediction',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchPredictionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetBatchPredictions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetBatchPredictions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBatchPredictions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListBatchPredictions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateExperiment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateExperiment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateExperimentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Experiment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExperiment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetExperiment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetExperimentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Experiment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetExperiments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetExperiments',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExperiments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListExperiments',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetEnvironment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEnvironmentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetEnvironments',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListEnvironments',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateEnvironment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateEnvironmentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateEnvironment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateEnvironmentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteEnvironment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteEnvironmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSystemMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetSystemMessage',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureFlag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetFeatureFlag',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureFlagRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureFlagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationFeatureFlags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetOrganizationFeatureFlags',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationFeatureFlagsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationFeatureFlagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateArtifact',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateArtifactRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Artifact.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetArtifact',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetArtifactRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Artifact.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetArtifacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetArtifacts',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetArtifactsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetArtifactsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteArtifact',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteArtifactRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateArtifactUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GenerateArtifactUploadURL',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateArtifactUploadURLRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateArtifactUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListArtifacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListArtifacts',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListArtifactsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListArtifactsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserIntegrationProviders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListUserIntegrationProviders',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationProvidersRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationProvidersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserIntegrations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListUserIntegrations',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUserIntegrationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisconnectUserIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DisconnectUserIntegration',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DisconnectUserIntegrationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateSsoAdminPortalURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GenerateSsoAdminPortalURL',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateSsoAdminPortalURLRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateSsoAdminPortalURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateDSyncAdminPortalURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GenerateDSyncAdminPortalURL',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateDSyncAdminPortalURLRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GenerateDSyncAdminPortalURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExchangeToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ExchangeToken',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ExchangeTokenRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ExchangeTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListGitProviderNamespaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListGitProviderNamespaces',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderNamespacesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderNamespacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListGitProviderRepositories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListGitProviderRepositories',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderRepositoriesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListGitProviderRepositoriesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConnectProjectToGitRepository(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ConnectProjectToGitRepository',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ConnectProjectToGitRepositoryRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ConnectProjectToGitRepositoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectGitIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetProjectGitIntegration',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetProjectGitIntegrationRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ProjectGitIntegration.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SeedProjectGitRepository(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/SeedProjectGitRepository',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SeedProjectGitRepositoryRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetRun',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRunRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Run.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetRuns',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRunsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListRuns',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRunsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateRun',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateRunRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Run.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateRun',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateRunRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Run.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteRun',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteRunRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRunSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetRunSummary',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRunSummaryRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.RunSummary.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRunCheckSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetRunCheckSummary',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRunCheckSummaryRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.RunCheckSummary.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LogRunHeartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/LogRunHeartbeat',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LogRunHeartbeatRequest.SerializeToString,
            google_dot_protobuf_dot_timestamp__pb2.Timestamp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMetric(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetMetric',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetMetricRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metric.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetMetrics',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetricsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListMetrics',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetricsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMetric(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateMetric',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateMetricRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metric.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LogMetric(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/LogMetric',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LogMetricRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMetric(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateMetric',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateMetricRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metric.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetMetadata',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetMetadataRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metadata.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetMetadata',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetadataRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetMetadataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListMetadata',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetadataRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListMetadataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateMetadata',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateMetadataRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metadata.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateMetadata',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateMetadataRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Metadata.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteMetadata',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteMetadataRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotificationPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetNotificationPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetNotificationPolicyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.NotificationPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetNotificationPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetNotificationPolicies',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetNotificationPoliciesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetNotificationPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNotificationPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListNotificationPolicies',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListNotificationPoliciesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListNotificationPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNotificationPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateNotificationPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateNotificationPolicyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.NotificationPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNotificationPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateNotificationPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateNotificationPolicyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.NotificationPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNotificationPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteNotificationPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteNotificationPolicyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetTag',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTagRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Tag.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetTags',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetTagsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListTags',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTagsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateTag',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateTagRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Tag.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateTag',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateTagRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Tag.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteTag',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteTagRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResourceCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetResourceCheck',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetResourceCheckRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ResourceCheck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListResourceChecks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListResourceChecks',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListResourceChecksRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListResourceChecksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateResourceCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateResourceCheck',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateResourceCheckRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ResourceCheck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetDataProfile',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDataProfileRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DataProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDataProfiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListDataProfiles',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDataProfilesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDataProfilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateDataProfile',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDataProfileRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DataProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateDataProfile',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateDataProfileRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DataProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateDataset',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDatasetRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Dataset.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetDataset',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDatasetRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Dataset.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetDatasets',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListDatasets',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteDataset',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteDatasetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDatasetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateDatasetVersion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDatasetVersionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDatasetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetDatasetVersion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDatasetVersionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetDatasetVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetDatasetVersions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetVersionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetDatasetVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDatasetVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListDatasetVersions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDatasetVersionAssignment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateDatasetVersionAssignment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateDatasetVersionAssignmentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersionAssignment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDatasetVersionAssignment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetDatasetVersionAssignment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDatasetVersionAssignmentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetVersionAssignment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDatasetVersionAssignment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteDatasetVersionAssignment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteDatasetVersionAssignmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDatasetVersionAssignments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListDatasetVersionAssignments',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionAssignmentsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListDatasetVersionAssignmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
